'use client'

import React, { useState } from 'react'
import { motion } from 'framer-motion'

function ContactFormSection() {
  const [formState, setFormState] = useState({
    name: '',
    email: '',
    message: ''
  })
  const [isSubmitting, setIsSubmitting] = useState(false)
  const [submitMessage, setSubmitMessage] = useState('')
  const [submitError, setSubmitError] = useState('')

  const handleChange = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
    setFormState({
      ...formState,
      [e.target.name]: e.target.value
    })
  }

  const handleSubmit = async (e: React.FormEvent<HTMLFormElement>) => {
    e.preventDefault()
    setIsSubmitting(true)
    setSubmitMessage('')
    setSubmitError('')

    const scriptUrl = 'https://script.google.com/macros/s/AKfycbw9PsKNye7pb-lNvjPDOOtRq_0bgPkvGlGgrGKcmP4TJl9tJF3I6gleMAhsoNGIbB5Etg/exec'

    try {
      const response = await fetch(scriptUrl, {
        method: 'POST',
        mode: 'no-cors',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify(formState),
      })

      // Since 'no-cors' mode doesn't give us access to the response status,
      // we'll assume success if no error is thrown
      setSubmitMessage('Thank you for your message. We\'ll get back to you soon!')
      setFormState({ name: '', email: '', message: '' })
    } catch (error) {
      console.error('Error submitting form:', error)
      setSubmitError(`Error: ${error instanceof Error ? error.message : String(error)}`)
    }

    setIsSubmitting(false)
  }

  return (
    <section className="cfs-section bg-gray-100 py-16">
      <div className="cfs-container max-w-3xl mx-auto px-4">
        <motion.h2 
          className="cfs-title text-3xl font-bold text-center mb-8"
          initial={{ opacity: 0, y: -20 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.5 }}
        >
          Contact Us
        </motion.h2>
        <motion.form 
          className="cfs-form bg-white shadow-md rounded px-8 pt-6 pb-8 mb-4"
          onSubmit={handleSubmit}
          initial={{ opacity: 0, y: 20 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.5, delay: 0.2 }}
        >
          <div className="cfs-form-group mb-4">
            <label className="cfs-label block text-gray-700 text-sm font-bold mb-2" htmlFor="cfs-name">
              Name
            </label>
            <input 
              className="cfs-input shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline"
              id="cfs-name"
              type="text"
              name="name"
              value={formState.name}
              onChange={handleChange}
              required
              placeholder="Your Name"
            />
          </div>
          <div className="cfs-form-group mb-4">
            <label className="cfs-label block text-gray-700 text-sm font-bold mb-2" htmlFor="cfs-email">
              Email
            </label>
            <input 
              className="cfs-input shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline"
              id="cfs-email"
              type="email"
              name="email"
              value={formState.email}
              onChange={handleChange}
              required
              placeholder="your.email@example.com"
            />
          </div>
          <div className="cfs-form-group mb-6">
            <label className="cfs-label block text-gray-700 text-sm font-bold mb-2" htmlFor="cfs-message">
              Message
            </label>
            <textarea 
              className="cfs-textarea shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline"
              id="cfs-message"
              name="message"
              value={formState.message}
              onChange={handleChange}
              required
              placeholder="Your message here..."
              rows={4}
            ></textarea>
          </div>
          <div className="cfs-form-group flex items-center justify-between">
            <button 
              className="cfs-submit-btn bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
              type="submit"
              disabled={isSubmitting}
            >
              {isSubmitting ? 'Sending...' : 'Send Message'}
            </button>
          </div>
          {submitMessage && (
            <motion.p 
              className="cfs-submit-message text-green-500 text-xs italic mt-4"
              initial={{ opacity: 0 }}
              animate={{ opacity: 1 }}
              transition={{ duration: 0.5 }}
            >
              {submitMessage}
            </motion.p>
          )}
          {submitError && (
            <motion.p 
              className="cfs-submit-error text-red-500 text-xs italic mt-4"
              initial={{ opacity: 0 }}
              animate={{ opacity: 1 }}
              transition={{ duration: 0.5 }}
            >
              {submitError}
            </motion.p>
          )}
        </motion.form>
      </div>
    </section>
  )
}

export default ContactFormSection